@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -119,6 +122,42 @@ class DataMigrationServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return DataMigrationServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> DataMigrationServiceTransport:
         """Returns the transport used by the client instance.
@@ -191,6 +230,26 @@ class DataMigrationServiceAsyncClient:
     ) -> pagers.ListMigrationJobsAsyncPager:
         r"""Lists migration jobs in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_list_migration_jobs():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.ListMigrationJobsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_migration_jobs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.ListMigrationJobsRequest, dict]):
                 The request object. Retrieve a list of all migration
@@ -218,7 +277,7 @@ class DataMigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -271,6 +330,25 @@ class DataMigrationServiceAsyncClient:
     ) -> clouddms_resources.MigrationJob:
         r"""Gets details of a single migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_get_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.GetMigrationJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_migration_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.GetMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -295,7 +373,7 @@ class DataMigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -345,6 +423,39 @@ class DataMigrationServiceAsyncClient:
         r"""Creates a new migration job in a given project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_create_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                migration_job = clouddms_v1.MigrationJob()
+                migration_job.reverse_ssh_connectivity.vm_ip = "vm_ip_value"
+                migration_job.reverse_ssh_connectivity.vm_port = 775
+                migration_job.type_ = "CONTINUOUS"
+                migration_job.source = "source_value"
+                migration_job.destination = "destination_value"
+
+                request = clouddms_v1.CreateMigrationJobRequest(
+                    parent="parent_value",
+                    migration_job_id="migration_job_id_value",
+                    migration_job=migration_job,
+                )
+
+                # Make the request
+                operation = client.create_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.CreateMigrationJobRequest, dict]):
                 The request object. Request message to create a new
@@ -389,7 +500,7 @@ class DataMigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, migration_job, migration_job_id])
         if request is not None and has_flattened_params:
@@ -449,6 +560,36 @@ class DataMigrationServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_update_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                migration_job = clouddms_v1.MigrationJob()
+                migration_job.reverse_ssh_connectivity.vm_ip = "vm_ip_value"
+                migration_job.reverse_ssh_connectivity.vm_port = 775
+                migration_job.type_ = "CONTINUOUS"
+                migration_job.source = "source_value"
+                migration_job.destination = "destination_value"
+
+                request = clouddms_v1.UpdateMigrationJobRequest(
+                    migration_job=migration_job,
+                )
+
+                # Make the request
+                operation = client.update_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.UpdateMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -486,7 +627,7 @@ class DataMigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([migration_job, update_mask])
         if request is not None and has_flattened_params:
@@ -545,6 +686,29 @@ class DataMigrationServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_delete_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.DeleteMigrationJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.DeleteMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -582,7 +746,7 @@ class DataMigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -636,6 +800,28 @@ class DataMigrationServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Start an already created migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_start_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.StartMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.start_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.StartMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -697,6 +883,28 @@ class DataMigrationServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Stops a running migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_stop_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.StopMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.stop_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.StopMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -759,6 +967,29 @@ class DataMigrationServiceAsyncClient:
         r"""Resume a migration job that is currently stopped and
         is resumable (was stopped during CDC phase).
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_resume_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.ResumeMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.resume_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.ResumeMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -822,6 +1053,29 @@ class DataMigrationServiceAsyncClient:
         destination and promoting the destination to be a
         standalone database.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_promote_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.PromoteMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.promote_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.PromoteMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -885,6 +1139,29 @@ class DataMigrationServiceAsyncClient:
         can reach the source and that all configuration and
         prerequisites are met.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_verify_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.VerifyMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.verify_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.VerifyMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -948,6 +1225,29 @@ class DataMigrationServiceAsyncClient:
         the destination instance to its original state and
         starting the migration process from scratch.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_restart_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.RestartMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.restart_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.RestartMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -1010,6 +1310,30 @@ class DataMigrationServiceAsyncClient:
         r"""Generate a SSH configuration script to configure the
         reverse SSH connectivity.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_generate_ssh_script():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                vm_creation_config = clouddms_v1.VmCreationConfig()
+                vm_creation_config.vm_machine_type = "vm_machine_type_value"
+
+                request = clouddms_v1.GenerateSshScriptRequest(
+                    vm_creation_config=vm_creation_config,
+                    vm="vm_value",
+                )
+
+                # Make the request
+                response = client.generate_ssh_script(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.GenerateSshScriptRequest, dict]):
                 The request object. Request message for
@@ -1063,6 +1387,27 @@ class DataMigrationServiceAsyncClient:
         r"""Retrieve a list of all connection profiles in a given
         project and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_list_connection_profiles():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.ListConnectionProfilesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_connection_profiles(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.ListConnectionProfilesRequest, dict]):
                 The request object. Request message for
@@ -1090,7 +1435,7 @@ class DataMigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1143,6 +1488,25 @@ class DataMigrationServiceAsyncClient:
     ) -> clouddms_resources.ConnectionProfile:
         r"""Gets details of a single connection profile.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_get_connection_profile():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.GetConnectionProfileRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_connection_profile(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.GetConnectionProfileRequest, dict]):
                 The request object. Request message for
@@ -1165,7 +1529,7 @@ class DataMigrationServiceAsyncClient:
                 A connection profile definition.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1215,6 +1579,38 @@ class DataMigrationServiceAsyncClient:
         r"""Creates a new connection profile in a given project
         and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_create_connection_profile():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                connection_profile = clouddms_v1.ConnectionProfile()
+                connection_profile.mysql.host = "host_value"
+                connection_profile.mysql.port = 453
+                connection_profile.mysql.username = "username_value"
+                connection_profile.mysql.password = "password_value"
+
+                request = clouddms_v1.CreateConnectionProfileRequest(
+                    parent="parent_value",
+                    connection_profile_id="connection_profile_id_value",
+                    connection_profile=connection_profile,
+                )
+
+                # Make the request
+                operation = client.create_connection_profile(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.CreateConnectionProfileRequest, dict]):
                 The request object. Request message for
@@ -1256,7 +1652,7 @@ class DataMigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, connection_profile, connection_profile_id])
         if request is not None and has_flattened_params:
@@ -1317,6 +1713,36 @@ class DataMigrationServiceAsyncClient:
         r"""Update the configuration of a single connection
         profile.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_update_connection_profile():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                connection_profile = clouddms_v1.ConnectionProfile()
+                connection_profile.mysql.host = "host_value"
+                connection_profile.mysql.port = 453
+                connection_profile.mysql.username = "username_value"
+                connection_profile.mysql.password = "password_value"
+
+                request = clouddms_v1.UpdateConnectionProfileRequest(
+                    connection_profile=connection_profile,
+                )
+
+                # Make the request
+                operation = client.update_connection_profile(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.UpdateConnectionProfileRequest, dict]):
                 The request object. Request message for
@@ -1353,7 +1779,7 @@ class DataMigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([connection_profile, update_mask])
         if request is not None and has_flattened_params:
@@ -1415,6 +1841,30 @@ class DataMigrationServiceAsyncClient:
         deleted if it is not in use by any active migration
         jobs.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_delete_connection_profile():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.DeleteConnectionProfileRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_connection_profile(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.DeleteConnectionProfileRequest, dict]):
                 The request object. Request message for
@@ -1452,7 +1902,7 @@ class DataMigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
