@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -260,6 +262,73 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -310,50 +379,22 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, DataMigrationServiceTransport):
             # transport is a DataMigrationServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -365,6 +406,15 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -388,6 +438,26 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
     ) -> pagers.ListMigrationJobsPager:
         r"""Lists migration jobs in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_list_migration_jobs():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.ListMigrationJobsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_migration_jobs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.ListMigrationJobsRequest, dict]):
                 The request object. Retrieve a list of all migration
@@ -415,7 +485,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -468,6 +538,25 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
     ) -> clouddms_resources.MigrationJob:
         r"""Gets details of a single migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_get_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.GetMigrationJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_migration_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.GetMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -492,7 +581,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -542,6 +631,39 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         r"""Creates a new migration job in a given project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_create_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                migration_job = clouddms_v1.MigrationJob()
+                migration_job.reverse_ssh_connectivity.vm_ip = "vm_ip_value"
+                migration_job.reverse_ssh_connectivity.vm_port = 775
+                migration_job.type_ = "CONTINUOUS"
+                migration_job.source = "source_value"
+                migration_job.destination = "destination_value"
+
+                request = clouddms_v1.CreateMigrationJobRequest(
+                    parent="parent_value",
+                    migration_job_id="migration_job_id_value",
+                    migration_job=migration_job,
+                )
+
+                # Make the request
+                operation = client.create_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.CreateMigrationJobRequest, dict]):
                 The request object. Request message to create a new
@@ -586,7 +708,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, migration_job, migration_job_id])
         if request is not None and has_flattened_params:
@@ -646,6 +768,36 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of a single migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_update_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                migration_job = clouddms_v1.MigrationJob()
+                migration_job.reverse_ssh_connectivity.vm_ip = "vm_ip_value"
+                migration_job.reverse_ssh_connectivity.vm_port = 775
+                migration_job.type_ = "CONTINUOUS"
+                migration_job.source = "source_value"
+                migration_job.destination = "destination_value"
+
+                request = clouddms_v1.UpdateMigrationJobRequest(
+                    migration_job=migration_job,
+                )
+
+                # Make the request
+                operation = client.update_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.UpdateMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -683,7 +835,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([migration_job, update_mask])
         if request is not None and has_flattened_params:
@@ -742,6 +894,29 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_delete_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.DeleteMigrationJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.DeleteMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -779,7 +954,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -833,6 +1008,28 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
     ) -> operation.Operation:
         r"""Start an already created migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_start_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.StartMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.start_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.StartMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -895,6 +1092,28 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
     ) -> operation.Operation:
         r"""Stops a running migration job.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_stop_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.StopMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.stop_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.StopMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -958,6 +1177,29 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         r"""Resume a migration job that is currently stopped and
         is resumable (was stopped during CDC phase).
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_resume_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.ResumeMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.resume_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.ResumeMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -1022,6 +1264,29 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         destination and promoting the destination to be a
         standalone database.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_promote_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.PromoteMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.promote_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.PromoteMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -1086,6 +1351,29 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         can reach the source and that all configuration and
         prerequisites are met.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_verify_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.VerifyMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.verify_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.VerifyMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -1150,6 +1438,29 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         the destination instance to its original state and
         starting the migration process from scratch.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_restart_migration_job():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.RestartMigrationJobRequest(
+                )
+
+                # Make the request
+                operation = client.restart_migration_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.RestartMigrationJobRequest, dict]):
                 The request object. Request message for
@@ -1213,6 +1524,30 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         r"""Generate a SSH configuration script to configure the
         reverse SSH connectivity.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_generate_ssh_script():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                vm_creation_config = clouddms_v1.VmCreationConfig()
+                vm_creation_config.vm_machine_type = "vm_machine_type_value"
+
+                request = clouddms_v1.GenerateSshScriptRequest(
+                    vm_creation_config=vm_creation_config,
+                    vm="vm_value",
+                )
+
+                # Make the request
+                response = client.generate_ssh_script(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.GenerateSshScriptRequest, dict]):
                 The request object. Request message for
@@ -1267,6 +1602,27 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         r"""Retrieve a list of all connection profiles in a given
         project and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_list_connection_profiles():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.ListConnectionProfilesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_connection_profiles(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.ListConnectionProfilesRequest, dict]):
                 The request object. Request message for
@@ -1294,7 +1650,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1347,6 +1703,25 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
     ) -> clouddms_resources.ConnectionProfile:
         r"""Gets details of a single connection profile.
 
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_get_connection_profile():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.GetConnectionProfileRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_connection_profile(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.GetConnectionProfileRequest, dict]):
                 The request object. Request message for
@@ -1369,7 +1744,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
                 A connection profile definition.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1419,6 +1794,38 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         r"""Creates a new connection profile in a given project
         and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_create_connection_profile():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                connection_profile = clouddms_v1.ConnectionProfile()
+                connection_profile.mysql.host = "host_value"
+                connection_profile.mysql.port = 453
+                connection_profile.mysql.username = "username_value"
+                connection_profile.mysql.password = "password_value"
+
+                request = clouddms_v1.CreateConnectionProfileRequest(
+                    parent="parent_value",
+                    connection_profile_id="connection_profile_id_value",
+                    connection_profile=connection_profile,
+                )
+
+                # Make the request
+                operation = client.create_connection_profile(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.CreateConnectionProfileRequest, dict]):
                 The request object. Request message for
@@ -1460,7 +1867,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, connection_profile, connection_profile_id])
         if request is not None and has_flattened_params:
@@ -1523,6 +1930,36 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         r"""Update the configuration of a single connection
         profile.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_update_connection_profile():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                connection_profile = clouddms_v1.ConnectionProfile()
+                connection_profile.mysql.host = "host_value"
+                connection_profile.mysql.port = 453
+                connection_profile.mysql.username = "username_value"
+                connection_profile.mysql.password = "password_value"
+
+                request = clouddms_v1.UpdateConnectionProfileRequest(
+                    connection_profile=connection_profile,
+                )
+
+                # Make the request
+                operation = client.update_connection_profile(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.UpdateConnectionProfileRequest, dict]):
                 The request object. Request message for
@@ -1559,7 +1996,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([connection_profile, update_mask])
         if request is not None and has_flattened_params:
@@ -1623,6 +2060,30 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         deleted if it is not in use by any active migration
         jobs.
 
+
+        .. code-block:: python
+
+            from google.cloud import clouddms_v1
+
+            def sample_delete_connection_profile():
+                # Create a client
+                client = clouddms_v1.DataMigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = clouddms_v1.DeleteConnectionProfileRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_connection_profile(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.clouddms_v1.types.DeleteConnectionProfileRequest, dict]):
                 The request object. Request message for
@@ -1660,7 +2121,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
